# Client

IGN GPAO Client est un module développée en [Python](https://www.python.org/) qui exécute des traitements (lignes de commande) en optimisant les ressources de la machine sur laquelle il est installé.

## Installation

1. Cloner le dépôt ign-gpao/client
2. Dans le répertoire du client, lancer la commande : `python3 -m client.client`

## Utilisation

## Développement

Le code peut-être analysé avec PyLint et Flake8.

### Tests

## Licence

Ce projet est sous licence CECILL-B (voir [LICENSE.md](https://github.com/ign-gpao/.github/blob/main/LICENSE.md)).

[![IGN](https://github.com/ign-gpao/.github/blob/main/images/logo_ign.png)](https://www.ign.fr)
